
************
***********
**********
*********
********
*******			Replication code for: 
******			"Losing Face and Sinking Costs:
****			Experimental Evidence on the Judgment of
***				Political and Military Leaders"
***
***
****			International Organization
*****
******
*******			Author: Jonathan Renshon
********
*********
**********
***********
************


* NOTE: This, along with the accompanying R code, replicates 
* all figures and tables from the published article and its supplementary 
* materials available online.


* Data:
* Replicating the tables and figures in this article requires two data files:
* (1) IO_replication_data.dta (this is the main data file)
* (2) means.csv (this contains descriptive statistics related to the power measures)



***
***
*** Figure 1 
***
***

* DESCRIPTION: Figure 1 is a visualization of the experimental protocol
* As such, there is no replication code for it.


***
***
*** Table 1 
***
***


* DESCRIPTION: Table 1 reports summary statistics for objecftive leadership scale
* NOTE: Please see accompanying R code.


***
***
*** Figure 2
***
***

* DESCRIPTION:  Power Measures by Leadership Group Membership
* NOTE: Please see accompanying R code.


***
***
*** Figure 3
***
***

* DESCRIPTION:  Manipulation Check: Effects of Essay Task on Status Beliefs
* NOTE: Please see accompanying R code.




***
***
*** Figure 4 (a-d)
***
***

* DESCRIPTION:  The Moderating Effect of Power
* NOTE: This code creates the CLARIFY output. To create Figure 4,  see accompanying R code.


clear all 

use "../Data/Raw Data/IO_replication_data.dta"

**
** For Leadership Group, 4(a)
**

* First, estimate model
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl leadershipgroup interactionGroup, sims(100000)

* Set all X values to their mean
setx mean, nocwdel 
setx lossntrlcntrl 1

* Generate first differences, switching from "control" subject to leader 
simqi, fd(ev) changex(leadershipgroup 0 1 interactionGroup 0 1) level(90)
simqi, fd(ev) changex(leadershipgroup 0 1 interactionGroup 0 1) level(95)
simqi, fd(ev) changex(leadershipgroup 0 1 interactionGroup 0 1) level(99)
drop b1 b2 b3 b4 b5 b6


* Now, do same thing only in CONTROL condition
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl leadershipgroup interactionGroup, sims(100000)
setx mean, nocwdel 
* Note that if treatment = 0, then interaction will equal 0 as well
setx lossntrlcntrl 0
simqi, fd(ev) changex(leadershipgroup 0 1) level(90)
simqi, fd(ev) changex(leadershipgroup 0 1) level(95)
simqi, fd(ev) changex(leadershipgroup 0 1) level(99)
drop b1 b2 b3 b4 b5 b6

**
** For Power Position Scale, 4(b)
**

* First, estimate model
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl zpps interactionZPPS, sims(100000)

* Set all X values to their mean
setx mean, nocwdel 
setx lossntrlcntrl 1

* Generate first differences, switching from average PPS to high PPS
simqi, fd(ev) changex(zpps mean max interactionZPPS mean max) level(90)
simqi, fd(ev) changex(zpps mean max interactionZPPS mean max) level(95)
simqi, fd(ev) changex(zpps mean max interactionZPPS mean max) level(99)
drop b*


* Now, do same thing only in CONTROL condition
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl zpps interactionZPPS, sims(100000)
setx mean, nocwdel 
setx lossntrlcntrl 0
simqi, fd(ev) changex(zpps mean max) level(90)
simqi, fd(ev) changex(zpps mean max) level(95)
simqi, fd(ev) changex(zpps mean max) level(99)
drop b*

**
** For Leadership Level, 4(c)
**

* First, estimate model
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl zdemo interactionDemo, sims(100000)

* Set all X values to their mean
setx mean, nocwdel 
setx lossntrlcntrl 1

* Generate first differences, switching from average zDemo to high zDemo
simqi, fd(ev) changex(zdemo mean max interactionDemo mean max) level(90)
simqi, fd(ev) changex(zdemo mean max interactionDemo mean max) level(95)
simqi, fd(ev) changex(zdemo mean max interactionDemo mean max) level(99)
drop b*

* Now, do same thing only in CONTROL condition
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl zdemo interactionDemo, sims(100000)
setx mean, nocwdel 
* Note that if treatment = 0, then interaction will equal 0 as well
setx lossntrlcntrl 0 
simqi, fd(ev) changex(zdemo mean max) level(90)
simqi, fd(ev) changex(zdemo mean max) level(95)
simqi, fd(ev) changex(zdemo mean max) level(99)
drop b*


**
** For Factor, 4(d)
**

** see here for how to run factor analysis with continuous and binary variables: http://www.ats.ucla.edu/stat/stata/faq/efa_categorical.htm

** install: findit polychoric

*generate our index based on factor analysis
polychoric   zdemo zpps leadershipgroup 
display r(sum_w)
global N = r(sum_w)
matrix r = r(R)
factormat r, n($N) factors(3)
rotate, horst	
predict factor1

*generate interaction term
gen interactionfactor1 = factor1 * lossntrlcntrl

* First, estimate model
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl factor1 interactionfactor1, sims(100000)

* Set all X values to their mean
setx mean, nocwdel 
setx lossntrlcntrl 1

* Generate first differences, switching from average factor to high factor
simqi, fd(ev) changex(factor1 mean max interactionfactor1 mean max) level(90)
simqi, fd(ev) changex(factor1 mean max interactionfactor1 mean max) level(95)
simqi, fd(ev) changex(factor1 mean max interactionfactor1 mean max) level(99)
drop b*

* Now, do same thing only in CONTROL condition
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl factor1 interactionfactor1, sims(100000)
setx mean, nocwdel 
* Note that if treatment = 0, then interaction will equal 0 as well
setx lossntrlcntrl 0 
simqi, fd(ev) changex(factor1 mean max) level(90)
simqi, fd(ev) changex(factor1 mean max) level(95)
simqi, fd(ev) changex(factor1 mean max) level(99)
drop b*


***
***
*** Figure 5
***
***


* DESCRIPTION:  Escalation by Status Condition and Power
* NOTE: This code creates CLARIFY output. To create figure,  see accompanying R code.


**
** Leadership Group, 5(a)
**

* First, estimate model
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl leadershipgroup interactionGroup staisum panas_pa panas_na sex demo_age demo_edu military1, sims(10000)

* Set all X values to their mean
setx mean, nocwdel

* Generate expected values for: Loss/ low power
setx lossntrlcntrl 1
setx leadershipgroup min interactionGroup min
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)

* Generate expected values for: Loss/ high power
setx lossntrlcntrl 1
setx leadershipgroup max interactionGroup max
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)

* Generate expected values for: Control/ low power
setx lossntrlcntrl 0
setx leadershipgroup min interactionGroup 0
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)

* Generate expected values for: Control/ high power
setx lossntrlcntrl 0
setx leadershipgroup max interactionGroup 0
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)
drop b*

**
** Power Position Scale, 5(b)
**

* First, estimate model
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl zpps interactionZPPS staisum panas_pa panas_na sex demo_age demo_edu military1, sims(10000)

* Set all X values to their mean
setx mean, nocwdel 

* Generate expected values for: Loss/Low Power
setx lossntrlcntrl 1
setx zpps min interactionZPPS min
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)

* Generate expected values for: Loss/ high power
setx lossntrlcntrl 1
setx zpps max interactionZPPS max
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)

* Generate expected values for: Control/low power
setx lossntrlcntrl 0
setx zpps min interactionZPPS 0
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)

* Generate expected values for: Control/high power
setx lossntrlcntrl 0
setx zpps max interactionZPPS 0
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)

drop b*


**
** Leadership Level, 5(c)
**


* First, estimate model
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl zdemo interactionDemo staisum panas_pa panas_na sex demo_age demo_edu military1, sims(10000)

* Set all X values to their mean
setx mean, nocwdel

* Generate expected values for:  Loss/ low power
setx lossntrlcntrl 1
setx zdemo min interactionDemo min
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)

* Generate expected values for: Loss/ high power
setx lossntrlcntrl 1
setx zdemo max interactionDemo max
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)

* Generate expected values for: Control/ low power
setx lossntrlcntrl 0
setx zdemo min interactionDemo 0
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)

* Generate expected values for: Control/ high power
setx lossntrlcntrl 0
setx zdemo max interactionDemo 0
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)
drop b*


**
** Factor, 5(d)
**

* First, estimate model
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl factor1 interactionfactor1 staisum panas_pa panas_na sex demo_age demo_edu military1, sims(10000)



* Set all X values to their mean
setx mean, nocwdel

* Generate expected values for:  Loss/ low power
setx lossntrlcntrl 1
setx factor1 min interactionfactor1 min
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)

* Generate expected values for: Loss/ high power
setx lossntrlcntrl 1
setx factor1 max interactionfactor1 max
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)

* Generate expected values for: Control/ low power
setx lossntrlcntrl 0
setx factor1 min interactionfactor1 0
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)

* Generate expected values for: Control/ high power
setx lossntrlcntrl 0
setx factor1 max interactionfactor1 0
simqi, ev level(90)
simqi, ev level(95)
simqi, ev level(99)
drop b*




**
** Average (blue shaded band in figure)
**

* First, for leadership group

* Estimate model
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl leadershipgroup interactionGroup staisum panas_pa panas_na sex demo_age demo_edu military1, sims(10000)
* Set X values to their mean, and treatment to "control"
setx mean, nocwdel
setx lossntrlcntrl 0
simqi, ev level(95)
* Set treatment to "Loss"
setx lossntrlcntrl 1
simqi, ev level(95)
drop b*


* Now, for PPS measure of power 
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl zpps interactionZPPS staisum panas_pa panas_na sex demo_age demo_edu military1, sims(10000)
setx mean, nocwdel
setx lossntrlcntrl 0
simqi, ev level(95)

setx lossntrlcntrl 1
simqi, ev level(95)
drop b*

* Now, for DEMO measure of power 
* First, estimate model
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl zdemo interactionDemo staisum panas_pa panas_na sex demo_age demo_edu military1, sims(10000)
setx mean, nocwdel
setx lossntrlcntrl 0
simqi, ev level(95)

setx lossntrlcntrl 1
simqi, ev level(95)
drop b*

* Now, for Factor measure of power 
* First, estimate model
estsimp regress island_pointsused island_roundsplayed lossntrlcntrl factor1 interactionfactor1 staisum panas_pa panas_na sex demo_age demo_edu military1, sims(10000)
setx mean, nocwdel
setx lossntrlcntrl 0
simqi, ev level(95)

setx lossntrlcntrl 1
simqi, ev level(95)
drop b*

***
***
*** Figure 6 (Appendix)
***
***

* DESCRIPTION:  Comparison of Sample Distributions
* NOTE: Please see accompanying R code.



***
***
*** Figure 7 (Appendix)
***
***

* DESCRIPTION:  Escalation by Status Condition
* NOTE: Please see accompanying R code.


***
***
*** Table 2 (Appendix)
***
***

* DESCRIPTION:  Leadership and Status Models (with controls)
* Models 1a-4a contain interactions and covariates in a linear regression
* Models 1b-4b contain interactions and covariates in a GLM models

* 1a
reg island_pointsused interactionGroup leadershipgroup lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 island_roundsplayed
estat ic

* 1b
glm island_pointsused interactionGroup leadershipgroup lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 island_roundsplayed
estat ic

* 2a
reg island_pointsused interactionDemo zdemo lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 island_roundsplayed
estat ic

* 2b
glm island_pointsused interactionDemo zdemo lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 island_roundsplayed
estat ic

* 3a
reg island_pointsused interactionZPPS zpps lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 island_roundsplayed
estat ic

* 3b
glm island_pointsused interactionZPPS zpps lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 island_roundsplayed
estat ic

* 4a
reg island_pointsused interactionfactor1 factor1 lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 island_roundsplayed
estat ic

* 4b
glm island_pointsused interactionfactor1 factor1 lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 island_roundsplayed
estat ic

* Models 5a-8a contain interactions and covariates in a linear regression, drop "rounds played" and exclude outliers
* Models 5b-8b contain interactions and covariates in a GLM models,  drop "rounds played" and exclude outliers


* 5a
reg island_pointsused interactionGroup leadershipgroup lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 if island_roundsplayedDIST<.95
estat ic

* 5b
glm island_pointsused interactionGroup leadershipgroup lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 if island_roundsplayedDIST<.95
estat ic

* 6a
reg island_pointsused interactionDemo zdemo lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 if island_roundsplayedDIST<.95
estat ic

* 6b
glm island_pointsused interactionDemo zdemo lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 if island_roundsplayedDIST<.95
estat ic

* 7a
reg island_pointsused interactionZPPS zpps lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 if island_roundsplayedDIST<.95
estat ic

* 7b
glm island_pointsused interactionZPPS zpps lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 if island_roundsplayedDIST<.95
estat ic

* 8a
reg island_pointsused interactionfactor1 factor1 lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 if island_roundsplayedDIST<.95
estat ic

* 8b
glm island_pointsused interactionfactor1 factor1 lossntrlcntrl staisum panas_pa panas_na sex demo_age demo_edu military1 if island_roundsplayedDIST<.95
estat ic





***
***
*** Table 3 (Appendix)
***
***

* DESCRIPTION:  Leadership and Status Models (with no controls)

* 1a 
reg island_pointsused lossntrlcntrl leadershipgroup interactionGroup island_roundsplayed
estat ic

* 1b 
glm island_pointsused lossntrlcntrl leadershipgroup interactionGroup island_roundsplayed
estat ic

* 2a 
reg island_pointsused lossntrlcntrl zdemo interactionDemo island_roundsplayed
estat ic

* 2b
glm island_pointsused lossntrlcntrl zdemo interactionDemo island_roundsplayed
estat ic

* 3a
reg island_pointsused lossntrlcntrl zpps interactionZPPS island_roundsplayed
estat ic

* 3b
glm island_pointsused lossntrlcntrl zpps interactionZPPS island_roundsplayed
estat ic

* 4a
reg island_pointsused lossntrlcntrl factor1 interactionfactor1 island_roundsplayed
estat ic

* 4b
glm island_pointsused lossntrlcntrl factor1 interactionfactor1 island_roundsplayed
estat ic


