###############
##############
#############
############
###########
##########
#########
########
#######
######			Replication Code for:
#####				"Losing Face and Sinking Costs:
####				Experimental Evidence on the Judgment of
####				Political And Military Leaders"
####				
#####				International Organization 
######			
#######			Author: Jonathan Renshon
########			
#########
##########			
###########
############
#############
##############
###############


# NOTE: This, along with the accompanying stata .do file, replicates 
# all figures and tables from the published article and its supplementary 
# materials available online.



#############						#############
#############		#############
#############						#############

# Call libraries for all the code that follows

# Analysis done with R version 3.0.3

library(foreign) 	# ver. 0.8-59
library(arm)  		# ver. 1.7-03
library(grid)		# included with R 3.0.3
library(gridExtra)	# ver. 0.9.1
library(ggplot2)	# ver. 1.0.0
library(sciplot)	# ver. 1.1-0
library(gplots)		# ver. 2.14.0


#############						#############
#############		#############
#############						#############

####
###
### Table 1 
###
####

##
## DESCRIPTION: Summary Statistics for Objective Leadership Scale
##

# Read data into memory
means<-read.csv("../Data/Raw Data/means.csv")

# Now, display means!
means

#############						#############
#############		#############
#############						#############


####
###
### Figure 2 
###
####

##
## DESCRIPTION: Power Measures by Leadership Group Membership
##

# First, load data in .csv format and save as "LDM"
# This is the data you will use for the rest of the code.

LDM <- read.csv("../Data/Raw Data/IO_replication_data.csv")



LDM$leadershipgroup <- factor(LDM$leadershipgroup,
                               levels = c(0,1),
                               labels = c("Control", "Leader"))


p <- ggplot(LDM, aes(x = zdemo, colour=factor(leadershipgroup), group=factor(leadershipgroup))) + geom_density(fill=NA, size=2)
p1<-p + geom_density(fill=NA, size=2)+ labs(colour = "Leadership Group") +xlab("Objective Leadersip Scale")+ylab("Density")
p2<-p1 + annotate("text", x = 0.5, y = .7, label = "Leaders: M=.30 , SD=.76") + annotate("text", x = 0.55, y = .65, label = "Controls: M=-.37, SD=.91")
   

ggsave(p2, file="zdemo.pdf")

colnames(LDM)
m <- ggplot(LDM, aes(x = zpps, colour=factor(leadershipgroup), group=factor(leadershipgroup)))
m1<-m + geom_density(fill=NA, size=2)+ labs(colour = "Leadership Group") +xlab("Subjective Power Position Scale")+ylab("Density")
m2<-m1 + annotate("text", x = -0.6, y = .7, label = "Leaders: M=.40 , SD=.70") + annotate("text", x = -0.58, y = .65, label = "Controls: M=-.47, SD=.89")

ggsave(m2, file="zpps.pdf")



#############						#############
#############		#############
#############						#############


####
###
### Figure 3a
###
####

##
## DESCRIPTION: Manipulation Check Plot 3a: Effect of Essay Task on Status Beliefs
##


plot.composite<-ggplot(LDM, aes(essay,status1234avg, fill=factor(essay)))+
stat_summary(fun.y = mean, geom="bar")+
stat_summary(fun.data = mean_cl_normal, geom = "pointrange", size=1.1)+
scale_x_discrete(name="Condition",limits=c("Status Loss","Neutral","Status Gain"))+scale_fill_hue(name="Condition")+
ggtitle('(a) Do you feel high or low (status/respect/power/prestige)') +
 theme( legend.position='none', panel.background=element_rect(fill="grey80"))+
scale_fill_manual(values=c("red", "antiquewhite4", "cadetblue"))+
scale_y_continuous(limits=c(0,7),name="Low                                            High")

#save plot
ggsave(filename="manipcheck.eps", plot=plot.composite)

#############						#############
#############		#############
#############						#############




####
###
### Figure 3b
###
####

##
## DESCRIPTION: Manipulation Check Plot 3b: Effect of Essay Task on Status Beliefs
##


valuestatus.plot<-ggplot(LDM, aes(essay,status_manipcheck_6, fill=factor(essay)))+
stat_summary(fun.y = mean, geom="bar")+
stat_summary(fun.data = mean_cl_normal, geom = "pointrange", size=1.1)+
scale_x_discrete(name="Condition",limits=c("Status Loss","Neutral","Status Gain"))+scale_fill_hue(name="Condition")+
ggtitle("(b) How much do you value having status?")+
theme(legend.position="none", panel.background=element_rect(fill="grey80"))+
scale_fill_manual(values=c("red", "antiquewhite4", "cadetblue"))+
scale_y_continuous(limits=c(0,7),name="Not at all                                            A lot")

#save plot
ggsave(filename="value-status.eps", plot=valuestatus.plot)


#############						#############
#############		#############
#############						#############




####
###
### Figure 4 (a-d)
###
####

##
## DESCRIPTION: The Moderating Effects of Power
##


# NOTE: This code creates Figure 4. It requires the output (in .csv form) from CLARIFY that is generated with the accompanying Stata code.  The CLARIFY output used in the article is also contained in a separate folder, which can be used if you prefer.
# If you do generate the CLARIFY output, please remember that small differences in results can be attributed to the simulation-based approach of CLARIFY.

# Load CLARIFY output
pps<-read.csv("../Data/CLARIFY Output/clarifyoutput-ZPPS.csv") 
leader.group<-read.csv("../Data/CLARIFY Output/clarifyoutput-leaderGroup.csv") 
leader.level<-read.csv("../Data/CLARIFY Output/clarifyoutput-leaderLevel.csv") 
factor.power<-read.csv("../Data/CLARIFY Output/clarifyoutput-factor.csv") 
#Make factor
factor(x=leader.group$X, labels=c("Status Loss", "Control"))
factor(x=leader.level$X, labels=c("Status Loss", "Control"))
factor(x=factor.power$X, labels=c("Status Loss", "Control"))

# 4(a)
plot1<-ggplot(data=leader.group, aes(x=X,y=ev, fill=X))
leader.plot<-plot1+geom_bar(stat="identity")+
scale_y_continuous(limits=c(-100,35),name="Change in E(money spent)")+
scale_x_discrete(name="Condition")+scale_fill_manual(values=c("cadetblue", "red"))+
theme(legend.position="none", panel.background=element_rect(fill="grey80"))+
geom_pointrange(aes(x=X,y=ev,ymin=X99lower, ymax=X99upper), color="grey30", size=1.1,linetype=1)+ 
geom_pointrange(aes(x=X,y=ev,ymin=X95lower, ymax=X95upper), color="black ", size=2.5,linetype=1)+ 
ggtitle("(a) Leadership Group")+theme(plot.title = element_text(size=22, face="bold"))+ 
theme(axis.title.x = element_text(face="bold", size=18), axis.text.x= element_text(size=18))+
theme(axis.title.y = element_text(face="bold", size=18), axis.text.y= element_text(size=18))+
geom_hline(aes(yintercept=0), colour="black", linetype="dashed")
ggsave(leader.plot, file="LeadershipPlot.eps")

# 4(b)
plot2<-ggplot(data=pps, aes(x=X,y=ev, fill=X))
pps.plot<-plot2+geom_bar(stat="identity")+
scale_y_continuous(limits=c(-100,35),name="Change in E(money spent)")+
scale_x_discrete(name="Condition")+scale_fill_manual(values=c("cadetblue", "red"))+
theme(legend.position="none", panel.background=element_rect(fill="grey80"))+
geom_pointrange(aes(x=X,y=ev,ymin= X99lower, ymax= X99upper), color="grey30", size=1.1,linetype=1)+ 
geom_pointrange(aes(x=X,y=ev,ymin= X95lower, ymax= X95upper), color="black", size=2.5,linetype=1)+
ggtitle("(b) Power Position Scale")+theme(plot.title = element_text(size=22, face="bold"))+ 
theme(axis.title.x = element_text(face="bold", size=18), axis.text.x= element_text(size=18))+
theme(axis.title.y = element_text(face="bold", size=18), axis.text.y= element_text(size=18))+
geom_hline(aes(yintercept=0), colour="black", linetype="dashed")
ggsave(pps.plot, file="PPSPlot.eps")


# 4(c)
plot3<-ggplot(data=leader.level, aes(x=X,y=ev, fill=X))
leaderlevel.plot<-plot3+geom_bar(stat="identity")+
scale_y_continuous(limits=c(-100,35),name="Change in E(money spent)")+
scale_x_discrete(name="Condition")+scale_fill_manual(values=c("cadetblue", "red"))+
theme(legend.position="none", panel.background=element_rect(fill="grey80"))+
geom_pointrange(aes(x=X,y=ev,ymin= X99lower, ymax= X99upper), color="grey30", size=1.1,linetype=1)+ 
geom_pointrange(aes(x=X,y=ev,ymin= X95lower, ymax= X95upper), color="black", size=2.5,linetype=1)+ 
ggtitle("(c) Leadership Level")+theme(plot.title = element_text(size=22, face="bold"))+ 
theme(axis.title.x = element_text(face="bold", size=18), axis.text.x= element_text(size=18))+
theme(axis.title.y = element_text(face="bold", size=18), axis.text.y= element_text(size=18))+
geom_hline(aes(yintercept=0), colour="black", linetype="dashed")
ggsave(leaderlevel.plot, file="LeaderLevelPlot.eps")

# 4(d)
plot4<-ggplot(data=factor.power, aes(x=X,y=ev, fill=X))
powerlevel.plot<-plot4+geom_bar(stat="identity")+
scale_y_continuous(limits=c(-100,35),name="Change in E(money spent)")+
scale_x_discrete(name="Condition")+scale_fill_manual(values=c("cadetblue", "red"))+
theme(legend.position="none", panel.background=element_rect(fill="grey80"))+
geom_pointrange(aes(x=X,y=ev,ymin= X99lower, ymax= X99upper), color="grey30", size=1.1,linetype=1)+ 
geom_pointrange(aes(x=X,y=ev,ymin= X95lower, ymax= X95upper), color="black", size=2.5,linetype=1)+ 
ggtitle("(d) Latent Power Factor")+theme(plot.title = element_text(size=22, face="bold"))+ 
theme(axis.title.x = element_text(face="bold", size=18), axis.text.x= element_text(size=18))+
theme(axis.title.y = element_text(face="bold", size=18), axis.text.y= element_text(size=18))+
geom_hline(aes(yintercept=0), colour="black", linetype="dashed")
ggsave(powerlevel.plot, file="FactorPlot.eps")



#############						#############
#############		#############
#############						#############



####
###
### Figure 5 (a-d)
###
####


##
## DESCRIPTION: Escalation by Status Condition and Power
##

# NOTE: This code creates Figure 5. It requires the output (in .csv form) from CLARIFY that is generated with the accompanying Stata code.  The CLARIFY output used in the article is also contained in a separate folder, which can be used if you prefer.
# If you do generate the CLARIFY output, please remember that small differences in results can be attributed to the simulation-based approach of CLARIFY.



## Load Data
pps<-read.csv("../Data/CLARIFY Output/EV-PPS.csv") 
leader<-read.csv("../Data/CLARIFY Output/EV-Leader.csv") 
demo<-read.csv("../Data/CLARIFY Output/EV-DEMO.csv")
factor<-read.csv("../Data/CLARIFY Output/EV-factor.csv")  
averageGROUP<-read.csv("../Data/CLARIFY Output/EV-averageGROUP.csv") 
averagePPS<-read.csv("../Data/CLARIFY Output/EV-averagePPS.csv") 
averageDEMO<-read.csv("../Data/CLARIFY Output/EV-averageDEMO.csv") 
averageFACTOR<-read.csv("../Data/CLARIFY Output/EV-averageFACTOR.csv") 


# 5(a)
plot1<-ggplot(data=leader, aes(x=X,y=ev, fill=X))
leader.ev<-plot1+ geom_ribbon(data= averageGROUP, aes(x=1:4, ymin=lowerci, ymax=upperci), fill="#CCFFFF")+geom_pointrange(aes(x=X,y=ev, ymin= X99lower, ymax= X99upper), color="grey30", size=1.1,linetype=1)+
geom_pointrange(aes(x=X,y=ev, ymin= X95lower, ymax= X95upper), size=1.8,linetype=1)+
scale_y_continuous(limits=c(-40,180),name="Escalation (Expected Value)")+theme(legend.position="none", panel.background=element_rect(fill="grey80"))+scale_x_discrete(name="Condition", labels=c("High Power \n(Control)", "Low Power \n(Control)", "High Power \n(Status Threat)", "Low Power \n(Status Threat)"))+ ggtitle("(a) Leadership Group")+theme(plot.title = element_text(size=22, face="bold"))+theme(axis.title.x = element_text(face="bold", size=12), axis.text.x= element_text(size=10))+theme(axis.title.y = element_text(face="bold", size=18), axis.text.y= element_text(size=18))+geom_smooth(data= averageGROUP, aes(x=X, y=ev, group=1), colour="blue", linetype=2)
ggsave(leader.ev, file="EVLeadershipPlot.pdf")

# 5(b)
plot2<-ggplot(data=pps, aes(x=X,y=ev, fill=X))
pps.ev<-plot2+ geom_ribbon(data= averagePPS, aes(x=1:4, ymin=lowerci, ymax=upperci), fill="#CCFFFF")+geom_pointrange(aes(x=X,y=ev, ymin= X99lower, ymax= X99upper), color="grey30", size=1.1,linetype=1)+
geom_pointrange(aes(x=X,y=ev, ymin= X95lower, ymax= X95upper), size=1.8,linetype=1)+scale_y_continuous(limits=c(-40,180),name="Escalation (Expected Value)")+theme(legend.position="none", panel.background=element_rect(fill="grey80"))+scale_x_discrete(name="Condition", labels=c("High Power \n(Control)", "Low Power \n(Control)", "High Power \n(Status Threat)", "Low Power \n(Status Threat)"))+ ggtitle("(b) Power Position Scale")+theme(plot.title = element_text(size=22, face="bold"))+theme(axis.title.x = element_text(face="bold", size=12), axis.text.x= element_text(size=10))+theme(axis.title.y = element_text(face="bold", size=18), axis.text.y= element_text(size=18))+geom_smooth(data= averagePPS, aes(x=X, y=ev, group=1), colour="blue", linetype=2)
ggsave(pps.ev, file="EVppsPlot.pdf")

# 5(c)
plot3<-ggplot(data=demo, aes(x=X,y=ev, fill=X))
demo.ev<-plot3+ geom_ribbon(data= averageDEMO, aes(x=1:4, ymin=lowerci, ymax=upperci), fill="#CCFFFF")+geom_pointrange(aes(x=X,y=ev, ymin= X99lower, ymax= X99upper), color="grey30",size=1.1,linetype=1)+
geom_pointrange(aes(x=X,y=ev, ymin= X95lower, ymax= X95upper), size=1.8,linetype=1)+ scale_y_continuous(limits=c(-40,180),name="Escalation (Expected Value)")+theme(legend.position="none", panel.background=element_rect(fill="grey80"))+scale_x_discrete(name="Condition", labels=c("High Power \n(Control)", "Low Power \n(Control)", "High Power \n(Status Threat)", "Low Power \n(Status Threat)"))+ ggtitle("(c) Leadership Level")+theme(plot.title = element_text(size=22, face="bold"))+theme(axis.title.x = element_text(face="bold", size=12), axis.text.x= element_text(size=10))+theme(axis.title.y = element_text(face="bold", size=18), axis.text.y= element_text(size=18))+geom_smooth(data= averageDEMO, aes(x=X, y=ev, group=1), colour="blue", linetype=2)

ggsave(demo.ev, file="EVdemoPlot.pdf")


# 5(d)
plot4<-ggplot(data=factor, aes(x=X,y=ev, fill=X))
factor.ev<-plot4+ geom_ribbon(data= averageFACTOR, aes(x=1:4, ymin=lowerci, ymax=upperci), fill="#CCFFFF")+geom_pointrange(aes(x=X,y=ev, ymin= X99lower, ymax= X99upper), color="grey30",size=1.1,linetype=1)+
geom_pointrange(aes(x=X,y=ev, ymin= X95lower, ymax= X95upper), size=1.8,linetype=1)+ scale_y_continuous(limits=c(-40,180),name="Escalation (Expected Value)")+theme(legend.position="none", panel.background=element_rect(fill="grey80"))+scale_x_discrete(name="Condition", labels=c("High Power \n(Control)", "Low Power \n(Control)", "High Power \n(Status Threat)", "Low Power \n(Status Threat)"))+ ggtitle("(d) Latent Power Factor")+theme(plot.title = element_text(size=22, face="bold"))+theme(axis.title.x = element_text(face="bold", size=12), axis.text.x= element_text(size=10))+theme(axis.title.y = element_text(face="bold", size=18), axis.text.y= element_text(size=18))+geom_smooth(data= averageFACTOR, aes(x=X, y=ev, group=1), colour="blue", linetype=2)

ggsave(factor.ev, file="EVfactorPlot.pdf")


#############						#############
#############		#############
#############						#############



####
###
### Figure 6 (Appendix)
###
####

##
## DESCRIPTION: Comparison of Sample distributions
##


LDM$leadership.group<-factor(LDM$leadershipgroup, labels=c("Control", "Leader"))

# Age
plot1<-ggplot(data=LDM, aes(factor(leadershipgroup), demo_age, fill=leadership.group))
age.plot<-plot1+geom_boxplot(outlier.colour = "blue", outlier.size = 3
)+ggtitle("Age")+theme(plot.title = element_text(size=22, face="bold"))+theme(legend.position="none", panel.background=element_rect(fill="grey80"))+scale_x_discrete(name="Sample Group")+scale_y_continuous(limits=c(0,80),name="Age")+scale_fill_manual(values=c("cadetblue", "red"))
ggsave(age.plot, file="AgePlot.eps")


# Education
plot2<-ggplot(data=LDM, aes(factor(leadershipgroup), demo_edu, fill=leadership.group))
education.plot<-plot2+geom_boxplot(outlier.colour = "blue", outlier.size = 3
)+ggtitle("Education")+theme(plot.title = element_text(size=22, face="bold"))+theme(legend.position="none", panel.background=element_rect(fill="grey80"))+scale_x_discrete(name="Sample Group")+scale_y_continuous(breaks=c(1, 2, 3, 4, 5), labels=c("High \nSchool","Some \nCollege", "2-year \nDegree", "4-year \nDegree", "Postgraduate \nDegree"), name="Education Level")+scale_fill_manual(values=c("cadetblue", "red"))
education.plot
ggsave(education.plot, file="EducationPlot.eps")



# Cognitive-Reflection Test (CRT)
plot3<-ggplot(data=LDM, aes(factor(leadership.group), CRT.SUM, fill=leadership.group))
crt.plot<-plot3+
	geom_boxplot(outlier.colour = "blue", outlier.size = 3)+
	ggtitle("Cognitive Reflection Task Score")+
	theme(plot.title = element_text(size=22, face="bold"))+
	theme(legend.position="none", panel.background=element_rect(fill="grey80"))+
	scale_x_discrete(name="Sample Group")+
	scale_y_continuous(name="CRT Score")+
	scale_fill_manual(values=c("cadetblue", "red"))
ggsave(crt.plot, file="CRTPlot.eps")

# WAIS
plot4<-ggplot(data=LDM, aes(factor(leadership.group), wais.SUM, fill=leadership.group))
wais.plot<-plot4+geom_boxplot(outlier.colour = "blue", outlier.size = 3
)+ggtitle("Wechsler Adult Intelligence Scale")+theme(plot.title = element_text(size=22, face="bold")+theme(legend.position="none", panel.background=element_rect(fill="grey80"))+scale_x_discrete(name="Sample Group")+scale_y_continuous(name="WAIS Score")+scale_fill_manual(values=c("cadetblue", "red"))
ggsave(wais.plot, file="WAISPlot.eps")


# SES
plot6<-ggplot(data=LDM, aes(factor(leadership.group), Demo_SES, fill=leadership.group))
ses.plot<-plot6+geom_boxplot(outlier.colour = "blue", outlier.size = 3
)+ggtitle("Socio-Economic Status")+theme(plot.title = element_text(size=22, face="bold"))+theme(legend.position="none", panel.background=element_rect(fill="grey80"))+scale_x_discrete(name="Sample Group")+scale_y_continuous(name="SES Score")+scale_fill_manual(values=c("cadetblue", "red"))
ggsave(ses.plot, file="SESPlot.eps")


#############						#############
#############		#############
#############						#############



####
###
### Figure 7 (Appendix)
###
####

##
## DESCRIPTION: Escalation by Status Condition
##


points.plot<-ggplot(LDM, aes(essay,island_pointsused, fill=factor(essay)))+
stat_summary(fun.y = mean, geom="bar")+
stat_summary(fun.data = mean_cl_normal, geom = "pointrange", size=1.1)+
scale_x_discrete(name="Condition",limits=c("Status Loss","Neutral","Status Gain"))+scale_fill_hue(name="Condition")+
 theme(title="")+
theme(legend.position="none", panel.background=element_rect(fill="grey80"))+
scale_fill_manual(values=c("red", "antiquewhite4", "cadetblue"))+
scale_y_continuous(limits=c(0,100),name="less               Escalation                more")
ggsave(filename="escalation-bycondition.eps", plot=points.plot)


#############						#############
#############		The End.
#############						#############
